.. _sec-installation-from-binaries:

Install from Pre-Built Binaries
===============================

Linux
-----

SageMath used to provide pre-built binaries for several Linux flavors.
This has been discontinued, as most major Linux distributions have
up-to-date distribution packages providing SageMath.
See :ref:`sec-GNU-Linux` for information.


macOS
-----

macOS binaries are available `from the 3-manifolds project
<https://github.com/3-manifolds/Sage_macOS/releases/>`_.  These
have been signed and notarized, eliminating various errors caused by
Apple's gatekeeper antimalware protections.

SageMath used to provide pre-built binaries for macOS on its mirrors.
This has been discontinued, and the old binaries that are still available
there are no longer supported.


Microsoft Windows
-----------------

SageMath used to provide pre-built binaries for Windows based on Cygwin.
This has been discontinued, and the old binaries that can be found
are no longer supported. Use Windows Subsystem for Linux instead.
